example

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2024 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Code generated by protoc-gen-go-setters. DO NOT EDIT. source: example/example.proto

Index

Constants

This section is empty.

Variables

var ExampleService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "example.ExampleService",
	HandlerType: (*ExampleServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListExamples",
			Handler:    _ExampleService_ListExamples_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "example/example.proto",
}

ExampleService_ServiceDesc is the grpc.ServiceDesc for ExampleService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_example_example_proto protoreflect.FileDescriptor

Functions

func RegisterExampleServiceServer

func RegisterExampleServiceServer(s grpc.ServiceRegistrar, srv ExampleServiceServer)

Types

type Example

type Example struct {
	Num int32 `protobuf:"varint,1,opt,name=num,proto3" json:"num,omitempty"`
	// contains filtered or unexported fields
}

func (*Example) Descriptor deprecated

func (*Example) Descriptor() ([]byte, []int)

Deprecated: Use Example.ProtoReflect.Descriptor instead.

func (*Example) GetNum

func (x *Example) GetNum() int32

func (*Example) ProtoMessage

func (*Example) ProtoMessage()

func (*Example) ProtoReflect

func (x *Example) ProtoReflect() protoreflect.Message

func (*Example) Reset

func (x *Example) Reset()

func (*Example) SetNum

func (x *Example) SetNum(in int32)

func (*Example) String

func (x *Example) String() string

type ExampleServiceClient

type ExampleServiceClient interface {
	ListExamples(ctx context.Context, in *ListExamplesRequest, opts ...grpc.CallOption) (*ListExamplesResponse, error)
}

ExampleServiceClient is the client API for ExampleService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ExampleServiceServer

type ExampleServiceServer interface {
	ListExamples(context.Context, *ListExamplesRequest) (*ListExamplesResponse, error)
	// contains filtered or unexported methods
}

ExampleServiceServer is the server API for ExampleService service. All implementations must embed UnimplementedExampleServiceServer for forward compatibility

type ListExamplesRequest

type ListExamplesRequest struct {
	PageToken string `protobuf:"bytes,1,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListExamplesRequest) Descriptor deprecated

func (*ListExamplesRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListExamplesRequest.ProtoReflect.Descriptor instead.

func (*ListExamplesRequest) GetPageToken

func (x *ListExamplesRequest) GetPageToken() string

func (*ListExamplesRequest) ProtoMessage

func (*ListExamplesRequest) ProtoMessage()

func (*ListExamplesRequest) ProtoReflect

func (x *ListExamplesRequest) ProtoReflect() protoreflect.Message

func (*ListExamplesRequest) Reset

func (x *ListExamplesRequest) Reset()

func (*ListExamplesRequest) SetPageToken

func (x *ListExamplesRequest) SetPageToken(in string)

func (*ListExamplesRequest) String

func (x *ListExamplesRequest) String() string

type ListExamplesResponse

type ListExamplesResponse struct {
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

func (*ListExamplesResponse) Descriptor deprecated

func (*ListExamplesResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListExamplesResponse.ProtoReflect.Descriptor instead.

func (*ListExamplesResponse) GetNextPageToken

func (x *ListExamplesResponse) GetNextPageToken() string

func (*ListExamplesResponse) ProtoMessage

func (*ListExamplesResponse) ProtoMessage()

func (*ListExamplesResponse) ProtoReflect

func (x *ListExamplesResponse) ProtoReflect() protoreflect.Message

func (*ListExamplesResponse) Reset

func (x *ListExamplesResponse) Reset()

func (*ListExamplesResponse) SetNextPageToken

func (x *ListExamplesResponse) SetNextPageToken(in string)

func (*ListExamplesResponse) String

func (x *ListExamplesResponse) String() string

type UnimplementedExampleServiceServer

type UnimplementedExampleServiceServer struct {
}

UnimplementedExampleServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedExampleServiceServer) ListExamples

type UnsafeExampleServiceServer

type UnsafeExampleServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeExampleServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ExampleServiceServer will result in compilation errors.

Jump to